@@ -18,7 +18,7 @@ IO::Socket::SSL::set_ctx_defaults(
      verify_mode => 0,
 );
 
-our $VERSION = '1.24.0';
+our $VERSION = '1.29.0';
 
 =head1 NAME
 
@@ -534,6 +534,7 @@ sub screenshot_thumbnail_file {
 	my ($self, %args) 	= @_;
 	my $file		= $args{file}	|| $self->error("Missing file in screenshot_thumbnail_file");
 
+	delete($args{file});
 	my $content = $self->screenshot_thumbnail(%args);
 
 	my $dir = dirname($file);
@@ -695,7 +696,7 @@ Required. instance_id to use for all screenshots.
 sub batch_create {
 	my ($self, %args) 	= @_;
 	my $file		= $args{file}		|| $self->error("Missing file in batch_create");
-	my $instance_id		= $args{instance_id}	|| $self->error("Missing instance_id} in batch_create");
+	my $instance_id		= $args{instance_id}	|| $self->error("Missing instance_id in batch_create");
 
 	delete $args{file};
 	return $self->return_post_reply(action => 'batch/create', parameters => { %args }, file => $file);
@@ -727,6 +728,65 @@ sub batch_info {
 }
 
 
+=head2 crawl_create()
+
+  $browshot->crawl_create(domain => 'blitapp.com', url => 'https://blitapp.com/', max => 50, instance_id => 65)
+
+Crawl a domain and screenshot all pages. See L<http://browshot.com/api/documentation#crawl_create> for the response format.
+
+Arguments:
+
+=over 4
+
+=item domain
+
+Required. Domain to crawl.
+
+=item url
+
+Required. URl to start with.
+
+=item instance_id
+
+Required. instance_id to use for all screenshots.
+
+=back
+
+=cut
+
+sub crawl_create {
+	my ($self, %args) = @_;
+	my $domain				= $args{domain}			|| $self->error("Missing domain in crawl_create");
+	my $url						= $args{url}				|| $self->error("Missing url in crawl_create");
+	my $instance_id		= $args{instance_id}	|| $self->error("Missing instance_id in crawl_create");
+
+	return $self->return_reply(action => 'crawl/create', parameters => { %args });
+}
+
+=head2 crawl__info()
+
+  $browshot->crawl__info(id => 5)
+
+Get information about a crawl_ requested previously. See L<http://browshot.com/api/documentation#crawl__info> for the response format.
+
+Arguments:
+
+=over 4
+
+=item id
+
+Required. Crawl ID.
+
+=back
+
+=cut
+
+sub crawl_info {
+	my ($self, %args) 	= @_;
+	my $id			= $args{id}	|| $self->error("Missing id in crawl_info");
+
+	return $self->return_reply(action => 'crawl/info', parameters => { %args });
+}
 
 =head2 account_info()
 
@@ -903,7 +963,7 @@ sub generic_error {
 
 =item 1.24.0
 
-C<screenshot_thumbnail_file creates> the directory structure as needed.
+C<screenshot_thumbnail_file> creates the directory structure as needed.
 
 =item 1.16.0
 
